# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/20_plot.ipynb.

# %% auto 0
__all__ = ['PROJ', 'PLOT', 'PROJECTION', 'CMAP', 'COLOR_MAP', 'COLOR', 'LABEL', 'TITLE', 'SUPTITLE', 'EDGECOLOR', 'FACECOLOR']

# %% ../nbs/20_plot.ipynb 5
PROJ = 'proj'
PLOT = 'plot'
PROJECTION = f'{PROJ}ection'
CMAP = 'cmap'
COLOR_MAP = 'color_map'
COLOR = 'color'
LABEL = 'label'
TITLE = 'title'
SUPTITLE = f'sup{TITLE}'
EDGECOLOR = f'edge{COLOR}'
FACECOLOR = f'face{COLOR}'

