# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/31_mthd.ipynb.

# %% auto 0
__all__ = ['DPT', 'PCA', 'UMAP', 'TSNE', 'PHATE', 'MAGIC', 'SCORE', 'ZSCORE', 'GZSCORE', 'LOG', 'LOG1P', 'OT', 'MMD', 'PSEUDO',
           'PSEUDOTIME', 'DPT_PSEUDOTIME']

# %% ../nbs/31_mthd.ipynb 4
from nchr import S_
from .exps import TIME

# %% ../nbs/31_mthd.ipynb 6
DPT   = 'dpt'
PCA   = 'pca'
UMAP  = 'umap'
TSNE  = 'tsne'
PHATE = 'phate'
MAGIC = 'magic'

SCORE = 'score'
ZSCORE = f'z{SCORE}'
GZSCORE = f'g{ZSCORE}'


LOG = 'log'
LOG1P = f'{LOG}1p'

OT = 'ot'
MMD = 'mmd'

# %% ../nbs/31_mthd.ipynb 7
PSEUDO = 'pseudo'
PSEUDOTIME = f'{PSEUDO}{TIME}'
DPT_PSEUDOTIME = f'{DPT}{S_}{PSEUDOTIME}'
