# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/04_dund.ipynb.

# %% auto 0
__all__ = ['MRO', 'NEW', 'CALL', 'INIT', 'NAME', 'ANNOTATIONS']

# %% ../nbs/04_dund.ipynb 5
MRO = 'mro'
NEW = 'new'
CALL = 'call'
INIT = 'init'
NAME = 'name'
ANNOTATIONS = 'annotations'

# %% ../nbs/04_dund.ipynb 6
__EQ__ = '__eq__'
__NE__ = '__ne__'
__LT__ = '__lt__'
__LE__ = '__le__'
__GT__ = '__gt__'
__GE__ = '__ge__'

__STR__ = '__str__'
__NEW__ = '__new__'
__DIR__ = '__dir__'
__LEN__ = '__len__'
__GET__ = '__get__'
__SET__ = '__set__'
__MRO__ = '__mro__'
__DOC__ = '__doc__'

__INIT__ = '__init__'
__REPR__ = '__repr__'
__CALL__ = '__call__'
__ITER__ = '__iter__'
__NEXT__ = '__next__'
__NAME__ = '__name__'


__HASH__ = '__hash__'
__BOOL__ = '__bool__'
__EXIT__ = '__exit__'
__DICT__ = '__dict__'

__ENTER__ = '__enter__'
__CLASS__ = '__class__'

__FORMAT__ = '__format__'

__GETATTR__ = '__getattr__'
__SETATTR__ = '__setattr__'
__DELATTR__ = '__delattr__'

__GETITEM__ = '__getitem__'
__SETITEM__ = '__setitem__'
__DELITEM__ = '__delitem__'

__PREPARE__ = '__prepare__'

__CONTAINS__ = '__contains__'
__REVERSED__ = '__reversed__'

__MOD__ = '__mod__'
__MUL__ = '__mul__'
__TRUEDIV__ = '__truediv__'
__FLOORDIV__ = '__floordiv__'
__ADD__ = '__add__'
__SUB__ = '__sub__'
__POW__ = '__pow__'

__RADD__ = '__radd__'
__RSUB__ = '__rsub__'
__RMUL__ = '__rmul__'
__RDIV__ = '__rdiv__'

__IADD__ = '__iadd__'
__ISUB__ = '__isub__'
__IMUL__ = '__imul__'
__IDIV__ = '__idiv__'

__BYTES__ = '__bytes__'
__INDEX__ = '__index__'
__SLICE__ = '__slice__'

__INIT_SUBCLASS__ = '__init_subclass__'
__INSTANCECHECK__ = '__instancecheck__'
__SUBCLASSCHECK__ = '__subclasscheck__'


# %% ../nbs/04_dund.ipynb 7
__SLOTS__ = '__slots__'

# %% ../nbs/04_dund.ipynb 9
__ALL__ = '__all__'
__FILE__ = '__file__'
__NAME__ = '__name__'
__SPEC__ = '__spec__'
__CACHED__ = '__cached__'
__LOADER__ = '__loader__'
__MODULE__ = '__module__'
__PACKAGE__ = '__package__'
__BUILTINS__ = '__builtins__'

# %% ../nbs/04_dund.ipynb 11
__AWAIT__ = '__await__'
__AENTER__ = '__aenter__'
__AEXIT__ = '__aexit__'
__ANEXT__ = '__anext__'
__AITER__ = '__aiter__'

__ABS__ = '__abs__'
__CMPLX__ = '__complex__'
__FLOAT__ = '__float__'
__INT__ = '__int__'
__ROUND__ = '__round__'

__DIVMOD__ = '__divmod__'
__RDIVMOD__ = '__rdivmod__'
__IPOW__ = '__ipow__'
__IMOD__ = '__imod__'
__IMATMUL__ = '__imatmul__'

__IFLOORDIV__ = '__ifloordiv__'
__ITRUEDIV__ = '__itruediv__'
__INVERT__ = '__invert__'
__LSHIFT__ = '__lshift__'
__RSHIFT__ = '__rshift__'

__ILSHIFT__ = '__ilshift__'
__IRSHIFT__ = '__irshift__'
__IOR__ = '__ior__'
__IXOR__ = '__ixor__'
__IAND__ = '__iand__'


# %% ../nbs/04_dund.ipynb 13
__FSPATH__ = '__fspath__'

# %% ../nbs/04_dund.ipynb 15
__MEMBERS__ = '__members__'
__RESTORE__ = '__restore__'
__METACLASS__ = '__metaclass__'

# %% ../nbs/04_dund.ipynb 17
__COPYING__   = '__copying__'
__DEFAULT__   = '__default__'
__PASSCLS__   = '__passcls__'
__PASSINS__   = '__passins__'

__PASSSELF__  = '__passself__'
__READONLY__  = '__readonly__'

__PAIRWISE__  = '__pairwise__'
__INNER_OP__  = '__inner_op__'

__ATTRSPECS__ = '__attrspecs__'
__SINGLETON__ = '__singleton__'
__INHERITING__ = '__inheriting__'

__INHERITABLE_MEMBERS__ = '__inheritable_members__'
