# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/62_pddf.ipynb.

# %% auto 0
__all__ = ['CAT', 'CATEGORY', 'CATEGORIES', 'COL', 'COLS', 'COLUMNS', 'GET', 'SHAPE']

# %% ../nbs/62_pddf.ipynb 5
CAT = 'cat'
CATEGORY = f'{CAT}egory'
CATEGORIES = f'{CAT}egories'

# %% ../nbs/62_pddf.ipynb 6
COL = 'col'
COLS = f'{COL}s'
COLUMNS = f'{COL}umns'

# %% ../nbs/62_pddf.ipynb 7
GET = 'get'
SHAPE = f'shape'
