# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/30_exps.ipynb.

# %% auto 0
__all__ = ['ID', 'IDX', 'CAT', 'ITEM', 'NAME', 'SEED', 'BATCH', 'TOTAL', 'METHOD', 'PCT', 'PERCENT', 'DAY', 'TIME', 'TIMEPOINT',
           'TIMEPOINTS', 'COUNT', 'NORM', 'NORMALIZED', 'CON', 'CONDITION', 'CONDITIONS', 'SAMPLE', 'SAMPLES',
           'TREATMENT', 'TREATMENTS', 'SENS', 'SENSITIVITY', 'SENSITIVITIES', 'CATEGORY', 'CATEGORIES', 'CLST',
           'LEIDEN', 'CLUSTER', 'LOUVAIN', 'CLIP', 'SUBSET', 'REPLACE', 'SD', 'SD1', 'SD2', 'SD3']

# %% ../nbs/30_exps.ipynb 4
from nchr import S_

# %% ../nbs/30_exps.ipynb 6
ID = 'id'
IDX = 'idx'
CAT = 'cat'

# %% ../nbs/30_exps.ipynb 7
ITEM = 'item'
NAME = 'name'
SEED = 'seed'

# %% ../nbs/30_exps.ipynb 8
BATCH = 'batch'
TOTAL = 'total'

# %% ../nbs/30_exps.ipynb 9
METHOD = 'method'

# %% ../nbs/30_exps.ipynb 10
PCT = 'pct'
PERCENT = 'percent'

# %% ../nbs/30_exps.ipynb 11
DAY = 'day'
TIME = 'time'
TIMEPOINT = f'{TIME}point'
TIMEPOINTS = f'{TIMEPOINT}s'

# %% ../nbs/30_exps.ipynb 12
COUNT = 'count'

# %% ../nbs/30_exps.ipynb 13
NORM = 'norm'
NORMALIZED = f'{NORM}alized'

# %% ../nbs/30_exps.ipynb 14
CON = 'con'
CONDITION = f'{CON}dition'
CONDITIONS = f'{CONDITION}s'

# %% ../nbs/30_exps.ipynb 15
SAMPLE = 'sample'
SAMPLES = f'{SAMPLE}s'

# %% ../nbs/30_exps.ipynb 16
TREATMENT = f'treatment'
TREATMENTS = f'{TREATMENT}s'

# %% ../nbs/30_exps.ipynb 17
SENS = 'sens'
SENSITIVITY = f'{SENS}itivity'
SENSITIVITIES = f'{SENS}itivities'

# %% ../nbs/30_exps.ipynb 18
CATEGORY = 'category'
CATEGORIES = 'categories'

# %% ../nbs/30_exps.ipynb 19
CLST = 'clst'
LEIDEN = 'leiden'
CLUSTER = 'cluster'
LOUVAIN = 'louvain'

# %% ../nbs/30_exps.ipynb 20
CLIP = 'clip'
SUBSET = 'subset'
REPLACE = 'replace'

# %% ../nbs/30_exps.ipynb 21
SD = 'sd'
SD1 = f'{SD}1'
SD2 = f'{SD}2'
SD3 = f'{SD}3'
