# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_args.ipynb.

# %% auto 0
__all__ = ['N', 'IDX', 'SEP', 'FMT', 'KEY', 'POS', 'CAT', 'ATTR', 'DESC', 'FUNC', 'KIND', 'TYPE', 'REPR', 'OPTS', 'SHOW', 'PREF',
           'KEYS', 'PREP', 'LINK', 'PATH', 'HUSH', 'QUIET', 'RAISE', 'FAILQ', 'SPEC', 'SPECS', 'ANTI', 'PTTN',
           'PATTERN', 'ANTI_PTTN', 'DEBUG', 'PRINT', 'VALUE', 'COLOR', 'LABEL', 'TITLE', 'NBINS', 'CUTOFF', 'MIXINS',
           'UNIQUE', 'HIDDEN', 'IGNORE', 'DEFAULT', 'INPLACE', 'VERBOSE', 'REVERSE', 'EXCLUDE', 'OPTIONAL', 'REQUIRED',
           'ASMEMBER', 'ABRV', 'SYMB', 'CONS', 'FMTFUNC', 'MOD', 'PKG', 'ARG', 'KWS', 'KWDS', 'ARGS', 'KWARGS', 'VARG',
           'VKWS', 'VARGS', 'VKWDS', 'VKWARGS', 'SELF', 'BEG', 'END', 'NEG', 'LEN', 'DIG', 'BRV', 'FIX', 'OVERWRITE',
           'OVERWRITABLE']

# %% ../nbs/02_args.ipynb 5
N = 'n'

# %% ../nbs/02_args.ipynb 6
IDX = 'idx'
SEP = 'sep'
FMT = 'fmt'
KEY = 'key'
POS = 'pos'
CAT = 'cat'

# %% ../nbs/02_args.ipynb 7
ATTR = 'attr'
DESC = 'desc'
FUNC = 'func'
KIND = 'kind'
TYPE = 'type'
REPR = 'repr'
OPTS = 'opts'
SHOW = 'show'
PREF = 'pref'
KEYS = 'keys'
PREP = 'prep'

# %% ../nbs/02_args.ipynb 8
LINK = 'link'
PATH = 'path'

# %% ../nbs/02_args.ipynb 9
HUSH = 'hush'
QUIET = 'quiet'
RAISE = 'raise'
FAILQ = 'failq'

# %% ../nbs/02_args.ipynb 10
SPEC = 'spec'
SPECS = f'{SPEC}s'

# %% ../nbs/02_args.ipynb 11
ANTI = 'anti'
PTTN = 'pttn'
PATTERN = 'pattern'

ANTI_PTTN = f'{ANTI}_{PTTN}'

# %% ../nbs/02_args.ipynb 12
DEBUG = 'debug'
PRINT = 'print'
VALUE = 'value'

COLOR = 'color'
LABEL = 'label'
TITLE = 'title'

NBINS = 'nbins'

# %% ../nbs/02_args.ipynb 13
CUTOFF = 'cutoff'
MIXINS = 'mixins'
UNIQUE = 'unique'

# %% ../nbs/02_args.ipynb 14
HIDDEN = 'hidden'
IGNORE = 'ignore'


# %% ../nbs/02_args.ipynb 15
DEFAULT = 'default'
INPLACE = 'inplace'
VERBOSE = 'verbose'
REVERSE = 'reverse'
EXCLUDE = 'exclude'


# %% ../nbs/02_args.ipynb 16
OPTIONAL = 'optional'
REQUIRED = 'required'

# %% ../nbs/02_args.ipynb 18
ASMEMBER = 'asmember'

# %% ../nbs/02_args.ipynb 20
ABRV = 'abrv'
SYMB = 'symb'

CONS = 'cons'

# %% ../nbs/02_args.ipynb 21
FMTFUNC = f'{FMT}{FUNC}'

# %% ../nbs/02_args.ipynb 24
MOD = 'mod'
PKG = 'pkg'

# %% ../nbs/02_args.ipynb 26
ARG = 'arg'
KWS = 'kws'
KWDS = 'kwds'
ARGS = f'{ARG}s'
KWARGS = f'kw{ARGS}'
VARG = f'v{ARG}'
VKWS = f'v{KWS}'
VARGS = f'v{ARGS}'
VKWDS = f'v{KWDS}'
VKWARGS = f'v{KWARGS}'
SELF = 'self'

# %% ../nbs/02_args.ipynb 28
BEG = 'beg' # beginning
END = 'end' # end / ending

POS = 'pos' # positive
NEG = 'neg' # nevative

LEN = 'len' # length
DIG = 'dig' # digits

BRV = 'brv' # brv / abbreviation
FIX = 'fix' # prefix / suffix

# %% ../nbs/02_args.ipynb 30
OVERWRITE = 'overwrite'
OVERWRITABLE = 'overwritable'
